@@ -13,7 +13,7 @@ try:
     from collections import OrderedDict
 except ImportError:
     # for py2.6 case
-    from ordereddict import OderedDict
+    from ordereddict import OrderedDict
 
 from six import StringIO
 import logging
@@ -133,7 +133,7 @@ def _to_dict(s):
 @_file_input
 def _to_list(s):
     try:
-        if isinstance(s, list):
+        if isinstance(s, (list, tuple)):
             return s
 
         v = json.loads(s)
@@ -172,6 +172,9 @@ def _to_int_list(s):
 
 @_file_input
 def _to_string_list(s):
+    if isinstance(s, (six.text_type, six.binary_type)):
+        return re.split(r'[\s\|\,]+', s)
+
     try:
         v = _to_list(s)
         _assert_string_list(v)
